@@ -14,18 +14,22 @@
 # License along with this library; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
-from functools import partial
+from __future__ import absolute_import
+from builtins import object
 
-from pyipmi.msgs import create_request_by_name
-from pyipmi.errors import DecodingError, CompletionCodeError
-from utils import check_completion_code
-from pyipmi.state import State
+# from functools import partial
 
-from pyipmi.msgs.chassis import \
+from .msgs import create_request_by_name
+# from pyipmi.errors import DecodingError, CompletionCodeError
+from .utils import check_completion_code
+from .state import State
+
+from .msgs.chassis import \
         CONTROL_POWER_DOWN, CONTROL_POWER_UP, CONTROL_POWER_CYCLE, \
         CONTROL_HARD_RESET, CONTROL_DIAGNOSTIC_INTERRUPT, \
         CONTROL_SOFT_SHUTDOWN
 
+
 class Chassis(object):
     def get_chassis_status(self):
         return ChassisStatus(self.send_message_with_name('GetChassisStatus'))
