@@ -1,3 +1,4 @@
+from __future__ import absolute_import
 # Copyright (c) 2014  Kontron Europe GmbH
 #
 # This library is free software; you can redistribute it and/or
@@ -14,7 +15,7 @@
 # License along with this library; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
-import constants
+from . import constants
 
 from . import register_message_class
 from . import Message
@@ -99,6 +100,19 @@ class GetChassisStatusRsp(Message):
             Bitfield.Bit('cooling_fault_detected', 1),
             Bitfield.ReservedBit(4, 0),
         ),
+        Optional(
+            UnsignedInt('front_panel_button_capabilities', 1),
+#            Bitfield('front_panel_button_capabilites', 1,
+#                Bitfield.Bit('power_off_disabled', 1),
+#                Bitfield.Bit('reset_disabled', 1),
+#                Bitfield.Bit('diagnostic_interrupt_disabled', 1),
+#                Bitfield.Bit('standby_disabled', 1),
+#                Bitfield.Bit('power_off_disable_allowed', 1),
+#                Bitfield.Bit('reset_disable_allowed', 1),
+#                Bitfield.Bit('diagnostic_interrupt_disable_allowed', 1),
+#                Bitfield.Bit('standby_disable_allowed', 1),
+#            ),
+        ),
     )
 
 
